#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "error.h"
#include "dbquery.h"
#include "cdbslib.h"
#include "loadfile.h"
#include "getref.h"

/* QRY_OBSMODE -- Query the database for the observation mode
 *
 */

void qry_obsmode (context *qry, char *reffile, char **cdbsname, int maxname)
{
    int		code, iname;
    char	*inst, *refname;
    char	obsmode[SZ_DBFIELD+1];

    char	*modefmt = "select a.modes from cdbs_mode a where "
	"a.instrument = ^ and a.file_select = 'Y' and a.reference_file_type "
	"in (select distinct b.reference_file_type from ^ b where b.file_name "
	"= ^)";

    /* Determine the instrument from the reference file name */

    code = get_icode_ref (reffile);

    /* Set up the query */

    ostdb_query_setup (qry->connection, "qry_obsmode", 1, STDB_SQL,
		       qry->server, qry->cdbs_db, db_error);

    stdb_bind_string (qry->connection, "modes", obsmode, SZ_DBFIELD);

    inst = strclone (strucase (enquote (inst_cdbs[code])));
    refname = strclone (strucase (enquote (reffile)));

    build_qry (qry->connection, modefmt, inst, cdbsfile[code], refname);

    /* Get the names of the observation mode fields from the database */

    iname = 0;
    while (ostdb_get_exec (qry->connection) == STDB_CONTINUE && 
	   iname < maxname-1) {

	clean_data (obsmode);
	cdbsname[iname++] = strclone (obsmode);
    }

    stdb_close_query (qry->connection);

    /* Signal the end of the array with a null string */

    cdbsname[iname] = strclone ("");

    /* Free dynamically allocated memory */

    free (inst);
    free (refname);
}
